Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesdna/DNA_material_types.h')
-rw-r--r--source/blender/makesdna/DNA_material_types.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/makesdna/DNA_material_types.h b/source/blender/makesdna/DNA_material_types.h
index 2349028685d..117ad1cab0d 100644
--- a/source/blender/makesdna/DNA_material_types.h
+++ b/source/blender/makesdna/DNA_material_types.h
@@ -150,7 +150,7 @@ typedef struct Material {
/* Ror buttons and render. */
char pr_type, use_nodes;
- short pr_lamp, pr_texture;
+ short pr_light, pr_texture;
/* Index for render passes. */
short index;
@@ -195,7 +195,7 @@ typedef struct Material {
/* **************** MATERIAL ********************* */
/* maximum number of materials per material array.
* (on object, mesh, lamp, etc.). limited by
* short mat_nr in verts, faces.
* -1 because for active material we store the index + 1 */
#define MAXMAT (32767-1)
@@ -195,7 +195,7 @@ typedef struct Material {
/* **************** MATERIAL ********************* */
/* maximum number of materials per material array.
- * (on object, mesh, lamp, etc.). limited by
+ * (on object, mesh, light, etc.). limited by
* short mat_nr in verts, faces.
* -1 because for active material we store the index + 1 */